# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKFastMarchingPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkFastMarchingReachedTargetNodesStoppingCriterionPython
else:
    import _itkFastMarchingReachedTargetNodesStoppingCriterionPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrix_fixedPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.itkPointPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkVectorPython
import itk.itkCovariantVectorPython
import itk.itkIndexPython
import itk.itkSizePython
import itk.itkOffsetPython
import itk.itkFastMarchingStoppingCriterionBasePython
import itk.itkImagePython
import itk.itkImageRegionPython
import itk.itkRGBPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBAPixelPython
import itk.itkNodePairPython
class itkFastMarchingReachedTargetNodesStoppingCriterionEnums(object):
    r"""Proxy of C++ itkFastMarchingReachedTargetNodesStoppingCriterionEnums class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    TargetCondition_OneTarget = _itkFastMarchingReachedTargetNodesStoppingCriterionPython.itkFastMarchingReachedTargetNodesStoppingCriterionEnums_TargetCondition_OneTarget
    
    TargetCondition_SomeTargets = _itkFastMarchingReachedTargetNodesStoppingCriterionPython.itkFastMarchingReachedTargetNodesStoppingCriterionEnums_TargetCondition_SomeTargets
    
    TargetCondition_AllTargets = _itkFastMarchingReachedTargetNodesStoppingCriterionPython.itkFastMarchingReachedTargetNodesStoppingCriterionEnums_TargetCondition_AllTargets
    

    def __init__(self, *args):
        r"""
        __init__(self) -> itkFastMarchingReachedTargetNodesStoppingCriterionEnums
        __init__(self, arg0) -> itkFastMarchingReachedTargetNodesStoppingCriterionEnums

        Parameters
        ----------
        arg0: itkFastMarchingReachedTargetNodesStoppingCriterionEnums const &

        """
        _itkFastMarchingReachedTargetNodesStoppingCriterionPython.itkFastMarchingReachedTargetNodesStoppingCriterionEnums_swiginit(self, _itkFastMarchingReachedTargetNodesStoppingCriterionPython.new_itkFastMarchingReachedTargetNodesStoppingCriterionEnums(*args))
    __swig_destroy__ = _itkFastMarchingReachedTargetNodesStoppingCriterionPython.delete_itkFastMarchingReachedTargetNodesStoppingCriterionEnums

# Register itkFastMarchingReachedTargetNodesStoppingCriterionEnums in _itkFastMarchingReachedTargetNodesStoppingCriterionPython:
_itkFastMarchingReachedTargetNodesStoppingCriterionPython.itkFastMarchingReachedTargetNodesStoppingCriterionEnums_swigregister(itkFastMarchingReachedTargetNodesStoppingCriterionEnums)

def itkFastMarchingReachedTargetNodesStoppingCriterionIF2IF2_New():
    return itkFastMarchingReachedTargetNodesStoppingCriterionIF2IF2.New()

class itkFastMarchingReachedTargetNodesStoppingCriterionIF2IF2(itk.itkFastMarchingStoppingCriterionBasePython.itkFastMarchingStoppingCriterionBaseIF2IF2):
    r"""Proxy of C++ itkFastMarchingReachedTargetNodesStoppingCriterionIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkFastMarchingReachedTargetNodesStoppingCriterionIF2IF2_Pointer"""
        return _itkFastMarchingReachedTargetNodesStoppingCriterionPython.itkFastMarchingReachedTargetNodesStoppingCriterionIF2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkFastMarchingReachedTargetNodesStoppingCriterionIF2IF2_Pointer"""
        return _itkFastMarchingReachedTargetNodesStoppingCriterionPython.itkFastMarchingReachedTargetNodesStoppingCriterionIF2IF2_Clone(self)

    def SetTargetCondition(self, iCondition):
        r"""
        SetTargetCondition(self, iCondition)

        Parameters
        ----------
        iCondition: itkFastMarchingReachedTargetNodesStoppingCriterionEnums::TargetCondition const &

        """
        return _itkFastMarchingReachedTargetNodesStoppingCriterionPython.itkFastMarchingReachedTargetNodesStoppingCriterionIF2IF2_SetTargetCondition(self, iCondition)

    def GetTargetCondition(self):
        r"""GetTargetCondition(self) -> itkFastMarchingReachedTargetNodesStoppingCriterionEnums::TargetCondition const &"""
        return _itkFastMarchingReachedTargetNodesStoppingCriterionPython.itkFastMarchingReachedTargetNodesStoppingCriterionIF2IF2_GetTargetCondition(self)

    def SetTargetOffset(self, _arg):
        r"""
        SetTargetOffset(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkFastMarchingReachedTargetNodesStoppingCriterionPython.itkFastMarchingReachedTargetNodesStoppingCriterionIF2IF2_SetTargetOffset(self, _arg)

    def GetTargetOffset(self):
        r"""GetTargetOffset(self) -> float"""
        return _itkFastMarchingReachedTargetNodesStoppingCriterionPython.itkFastMarchingReachedTargetNodesStoppingCriterionIF2IF2_GetTargetOffset(self)

    def SetNumberOfTargetsToBeReached(self, iN):
        r"""
        SetNumberOfTargetsToBeReached(self, iN)

        Parameters
        ----------
        iN: unsigned long const &

        """
        return _itkFastMarchingReachedTargetNodesStoppingCriterionPython.itkFastMarchingReachedTargetNodesStoppingCriterionIF2IF2_SetNumberOfTargetsToBeReached(self, iN)

    def SetTargetNodes(self, iNodes):
        r"""
        SetTargetNodes(self, iNodes)

        Parameters
        ----------
        iNodes: std::vector< itkIndex2,std::allocator< itkIndex2 > > const &

        """
        return _itkFastMarchingReachedTargetNodesStoppingCriterionPython.itkFastMarchingReachedTargetNodesStoppingCriterionIF2IF2_SetTargetNodes(self, iNodes)

    def SetCurrentNode(self, iNode):
        r"""
        SetCurrentNode(self, iNode)

        Parameters
        ----------
        iNode: itkIndex2 const &

        """
        return _itkFastMarchingReachedTargetNodesStoppingCriterionPython.itkFastMarchingReachedTargetNodesStoppingCriterionIF2IF2_SetCurrentNode(self, iNode)
    __swig_destroy__ = _itkFastMarchingReachedTargetNodesStoppingCriterionPython.delete_itkFastMarchingReachedTargetNodesStoppingCriterionIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkFastMarchingReachedTargetNodesStoppingCriterionIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkFastMarchingReachedTargetNodesStoppingCriterionPython.itkFastMarchingReachedTargetNodesStoppingCriterionIF2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkFastMarchingReachedTargetNodesStoppingCriterionIF2IF2

        Create a new object of the class itkFastMarchingReachedTargetNodesStoppingCriterionIF2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkFastMarchingReachedTargetNodesStoppingCriterionIF2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkFastMarchingReachedTargetNodesStoppingCriterionIF2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkFastMarchingReachedTargetNodesStoppingCriterionIF2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkFastMarchingReachedTargetNodesStoppingCriterionIF2IF2 in _itkFastMarchingReachedTargetNodesStoppingCriterionPython:
_itkFastMarchingReachedTargetNodesStoppingCriterionPython.itkFastMarchingReachedTargetNodesStoppingCriterionIF2IF2_swigregister(itkFastMarchingReachedTargetNodesStoppingCriterionIF2IF2)

def itkFastMarchingReachedTargetNodesStoppingCriterionIF3IF3_New():
    return itkFastMarchingReachedTargetNodesStoppingCriterionIF3IF3.New()

class itkFastMarchingReachedTargetNodesStoppingCriterionIF3IF3(itk.itkFastMarchingStoppingCriterionBasePython.itkFastMarchingStoppingCriterionBaseIF3IF3):
    r"""Proxy of C++ itkFastMarchingReachedTargetNodesStoppingCriterionIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkFastMarchingReachedTargetNodesStoppingCriterionIF3IF3_Pointer"""
        return _itkFastMarchingReachedTargetNodesStoppingCriterionPython.itkFastMarchingReachedTargetNodesStoppingCriterionIF3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkFastMarchingReachedTargetNodesStoppingCriterionIF3IF3_Pointer"""
        return _itkFastMarchingReachedTargetNodesStoppingCriterionPython.itkFastMarchingReachedTargetNodesStoppingCriterionIF3IF3_Clone(self)

    def SetTargetCondition(self, iCondition):
        r"""
        SetTargetCondition(self, iCondition)

        Parameters
        ----------
        iCondition: itkFastMarchingReachedTargetNodesStoppingCriterionEnums::TargetCondition const &

        """
        return _itkFastMarchingReachedTargetNodesStoppingCriterionPython.itkFastMarchingReachedTargetNodesStoppingCriterionIF3IF3_SetTargetCondition(self, iCondition)

    def GetTargetCondition(self):
        r"""GetTargetCondition(self) -> itkFastMarchingReachedTargetNodesStoppingCriterionEnums::TargetCondition const &"""
        return _itkFastMarchingReachedTargetNodesStoppingCriterionPython.itkFastMarchingReachedTargetNodesStoppingCriterionIF3IF3_GetTargetCondition(self)

    def SetTargetOffset(self, _arg):
        r"""
        SetTargetOffset(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkFastMarchingReachedTargetNodesStoppingCriterionPython.itkFastMarchingReachedTargetNodesStoppingCriterionIF3IF3_SetTargetOffset(self, _arg)

    def GetTargetOffset(self):
        r"""GetTargetOffset(self) -> float"""
        return _itkFastMarchingReachedTargetNodesStoppingCriterionPython.itkFastMarchingReachedTargetNodesStoppingCriterionIF3IF3_GetTargetOffset(self)

    def SetNumberOfTargetsToBeReached(self, iN):
        r"""
        SetNumberOfTargetsToBeReached(self, iN)

        Parameters
        ----------
        iN: unsigned long const &

        """
        return _itkFastMarchingReachedTargetNodesStoppingCriterionPython.itkFastMarchingReachedTargetNodesStoppingCriterionIF3IF3_SetNumberOfTargetsToBeReached(self, iN)

    def SetTargetNodes(self, iNodes):
        r"""
        SetTargetNodes(self, iNodes)

        Parameters
        ----------
        iNodes: std::vector< itkIndex3,std::allocator< itkIndex3 > > const &

        """
        return _itkFastMarchingReachedTargetNodesStoppingCriterionPython.itkFastMarchingReachedTargetNodesStoppingCriterionIF3IF3_SetTargetNodes(self, iNodes)

    def SetCurrentNode(self, iNode):
        r"""
        SetCurrentNode(self, iNode)

        Parameters
        ----------
        iNode: itkIndex3 const &

        """
        return _itkFastMarchingReachedTargetNodesStoppingCriterionPython.itkFastMarchingReachedTargetNodesStoppingCriterionIF3IF3_SetCurrentNode(self, iNode)
    __swig_destroy__ = _itkFastMarchingReachedTargetNodesStoppingCriterionPython.delete_itkFastMarchingReachedTargetNodesStoppingCriterionIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkFastMarchingReachedTargetNodesStoppingCriterionIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkFastMarchingReachedTargetNodesStoppingCriterionPython.itkFastMarchingReachedTargetNodesStoppingCriterionIF3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkFastMarchingReachedTargetNodesStoppingCriterionIF3IF3

        Create a new object of the class itkFastMarchingReachedTargetNodesStoppingCriterionIF3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkFastMarchingReachedTargetNodesStoppingCriterionIF3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkFastMarchingReachedTargetNodesStoppingCriterionIF3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkFastMarchingReachedTargetNodesStoppingCriterionIF3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkFastMarchingReachedTargetNodesStoppingCriterionIF3IF3 in _itkFastMarchingReachedTargetNodesStoppingCriterionPython:
_itkFastMarchingReachedTargetNodesStoppingCriterionPython.itkFastMarchingReachedTargetNodesStoppingCriterionIF3IF3_swigregister(itkFastMarchingReachedTargetNodesStoppingCriterionIF3IF3)

